==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translation type="vanished">Ni izbranih entitet.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Ni izbranih entitet.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 na plasti &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 na %3 plasteh</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation>%1 entitet na plasti &apos;%2&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 Entities on %2 Layers</source>
        <translation>%1 entitet na %2 plasteh</translation>
    </message>
    <message>
        <source>Entities</source>
        <translation type="vanished">Entitete</translation>
    </message>
    <message>
        <source>on</source>
        <translation type="vanished">na</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translation type="vanished">Plast &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translation type="vanished">%1 Plasti</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translation>Izbrane entitete: %1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/SelectionDisplay/ts/SelectionDisplay_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SelectionDisplay</name>
    <message>
        <source>No selected entities.</source>
        <translation type="vanished">Ni izbranih entitet.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.js" line="+58"/>
        <source>No entities selected.</source>
        <translation>Ni izbranih entitet.</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>%1 %2 on Layer &apos;%3&apos;</source>
        <translation>%1 %2 na plasti &apos;%3&apos;</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>%1 %2 on %3 Layers</source>
        <translation>%1 %2 na %3 plasteh</translation>
    </message>
    <message numerus="yes">
        <location line="+4"/>
        <source>%n Entities on Layer &apos;%1&apos;</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>%n Entities</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+0"/>
        <source>%n Layers</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 Entities on Layer &apos;%2&apos;</source>
        <translation type="vanished">%1 entitet na plasti &apos;%2&apos;</translation>
    </message>
    <message>
        <source>%1 Entities on %2 Layers</source>
        <translation type="vanished">%1 entitet na %2 plasteh</translation>
    </message>
    <message>
        <source>Entities</source>
        <translation type="vanished">Entitete</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>on</source>
        <translation>na</translation>
    </message>
    <message>
        <source>Layer &apos;%1&apos;</source>
        <translation type="vanished">Plast &apos;%1&apos;</translation>
    </message>
    <message>
        <source>%1 Layers</source>
        <translation type="vanished">%1 Plasti</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Selected entities:
%1.</source>
        <translation>Izbrane entitete: %1.</translation>
    </message>
    <message>
        <location filename="../SelectionDisplay.ui" line="+26"/>
        <source>Form</source>
        <translation>Obrazec</translation>
    </message>
</context>
</TS>
